summaryrefslogtreecommitdiff
path: root/include/svx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-11-04 14:45:00 +0200
committerNoel Grandin <noel@peralex.com>2014-11-04 14:45:58 +0200
commita3e2b884f33435eef369ce8cb8eee4bdc5db95af (patch)
tree849073519a8722bdcb3897787a9872e73ed0d227 /include/svx
parentd1974ddf3a84d2a4a3082920f812857c85218fc2 (diff)
rename nWink->nAngle
Change-Id: I3a4cec65307c517684d4f8a291ca73b6a212a857
Diffstat (limited to 'include/svx')
-rw-r--r--include/svx/obj3d.hxx2
-rw-r--r--include/svx/scene3d.hxx4
-rw-r--r--include/svx/svdedtv.hxx8
-rw-r--r--include/svx/svdglev.hxx4
-rw-r--r--include/svx/svdglue.hxx16
-rw-r--r--include/svx/svdmodel.hxx2
-rw-r--r--include/svx/svdoashp.hxx8
-rw-r--r--include/svx/svdobj.hxx14
-rw-r--r--include/svx/svdocirc.hxx2
-rw-r--r--include/svx/svdoedge.hxx4
-rw-r--r--include/svx/svdograf.hxx4
-rw-r--r--include/svx/svdogrp.hxx8
-rw-r--r--include/svx/svdomeas.hxx4
-rw-r--r--include/svx/svdorect.hxx4
-rw-r--r--include/svx/svdotext.hxx4
-rw-r--r--include/svx/svdovirt.hxx8
-rw-r--r--include/svx/svdpoev.hxx2
-rw-r--r--include/svx/svdsnpv.hxx4
-rw-r--r--include/svx/svdtrans.hxx18
19 files changed, 60 insertions, 60 deletions
diff --git a/include/svx/obj3d.hxx b/include/svx/obj3d.hxx
index ac7e52493ef7..bdba2c34dae2 100644
--- a/include/svx/obj3d.hxx
+++ b/include/svx/obj3d.hxx
@@ -178,7 +178,7 @@ public:
// which is vertical to the screen, plus a shift of the scene.
// This means that also the scene (E3dScene) must define this
// routine as virtual in its class.
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
// get wireframe polygon for local object. No transform is applied.
basegfx::B3DPolyPolygon CreateWireframe() const;
diff --git a/include/svx/scene3d.hxx b/include/svx/scene3d.hxx
index 332fa2a7fa8d..aa24245a1948 100644
--- a/include/svx/scene3d.hxx
+++ b/include/svx/scene3d.hxx
@@ -210,8 +210,8 @@ public:
virtual void NbcSetTransform(const basegfx::B3DHomMatrix& rMatrix) SAL_OVERRIDE;
virtual void SetTransform(const basegfx::B3DHomMatrix& rMatrix) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
- void RotateScene(const Point& rRef, long nWink, double sn, double cs);
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
+ void RotateScene(const Point& rRef, long nAngle, double sn, double cs);
// TakeObjName...() is for the display in the UI, for example "3 frames selected".
virtual OUString TakeObjNameSingul() const SAL_OVERRIDE;
diff --git a/include/svx/svdedtv.hxx b/include/svx/svdedtv.hxx
index 13f1159bb812..e29a065f485d 100644
--- a/include/svx/svdedtv.hxx
+++ b/include/svx/svdedtv.hxx
@@ -215,12 +215,12 @@ public:
void ResizeMarkedObj(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bCopy=false);
void ResizeMultMarkedObj(const Point& rRef, const Fraction& xFact, const Fraction& yFact, const bool bCopy, const bool bWdh, const bool bHgt);
long GetMarkedObjRotate() const;
- void RotateMarkedObj(const Point& rRef, long nWink, bool bCopy=false);
+ void RotateMarkedObj(const Point& rRef, long nAngle, bool bCopy=false);
void MirrorMarkedObj(const Point& rRef1, const Point& rRef2, bool bCopy=false);
void MirrorMarkedObjHorizontal(bool bCopy=false);
void MirrorMarkedObjVertical(bool bCopy=false);
long GetMarkedObjShear() const;
- void ShearMarkedObj(const Point& rRef, long nWink, bool bVShear=false, bool bCopy=false);
+ void ShearMarkedObj(const Point& rRef, long nAngle, bool bVShear=false, bool bCopy=false);
void CrookMarkedObj(const Point& rRef, const Point& rRad, SdrCrookMode eMode, bool bVertical=false, bool bNoContortion=false, bool bCopy=false);
void DistortMarkedObj(const Rectangle& rRef, const XPolygon& rDistortedRect, bool bNoContortion=false, bool bCopy=false);
@@ -230,12 +230,12 @@ public:
void MoveAllMarked(const Size& rSiz, bool bCopy=false) { MoveMarkedObj (rSiz,bCopy); }
void ResizeAllMarked(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bCopy=false) { ResizeMarkedObj (rRef,xFact,yFact,bCopy); }
long GetAllMarkedRotate() const { return GetMarkedObjRotate(); }
- void RotateAllMarked(const Point& rRef, long nWink, bool bCopy=false) { RotateMarkedObj(rRef,nWink,bCopy); }
+ void RotateAllMarked(const Point& rRef, long nAngle, bool bCopy=false) { RotateMarkedObj(rRef,nAngle,bCopy); }
void MirrorAllMarked(const Point& rRef1, const Point& rRef2, bool bCopy=false) { MirrorMarkedObj(rRef1,rRef2,bCopy); }
void MirrorAllMarkedHorizontal(bool bCopy=false) { MirrorMarkedObjHorizontal(bCopy); }
void MirrorAllMarkedVertical(bool bCopy=false) { MirrorMarkedObjVertical(bCopy); }
long GetAllMarkedShear() const { return GetMarkedObjShear(); }
- void ShearAllMarked(const Point& rRef, long nWink, bool bVShear=false, bool bCopy=false) { ShearMarkedObj(rRef,nWink,bVShear,bCopy); }
+ void ShearAllMarked(const Point& rRef, long nAngle, bool bVShear=false, bool bCopy=false) { ShearMarkedObj(rRef,nAngle,bVShear,bCopy); }
void CrookAllMarked(const Point& rRef, const Point& rRad, SdrCrookMode eMode, bool bVertical=false, bool bNoContortion=false, bool bCopy=false) { CrookMarkedObj(rRef,rRad,eMode,bVertical,bNoContortion,bCopy); }
void CopyMarked() { CopyMarkedObj(); }
bool IsMoveAllowed() const { ForcePossibilities(); return bMoveAllowed && !bMoveProtect; }
diff --git a/include/svx/svdglev.hxx b/include/svx/svdglev.hxx
index 564831d58576..cc1022c18e47 100644
--- a/include/svx/svdglev.hxx
+++ b/include/svx/svdglev.hxx
@@ -79,11 +79,11 @@ public:
void MoveMarkedGluePoints (const Size& rSiz, bool bCopy=false);
void ResizeMarkedGluePoints(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bCopy=false);
- void RotateMarkedGluePoints(const Point& rRef, long nWink, bool bCopy=false);
+ void RotateMarkedGluePoints(const Point& rRef, long nAngle, bool bCopy=false);
void MirrorMarkedGluePoints(const Point& rRef1, const Point& rRef2, bool bCopy=false);
void MirrorMarkedGluePointsHorizontal(bool bCopy=false);
void MirrorMarkedGluePointsVertical(bool bCopy=false);
- void ShearMarkedGluePoints(const Point& rRef, long nWink, bool bVShear=false, bool bCopy=false);
+ void ShearMarkedGluePoints(const Point& rRef, long nAngle, bool bVShear=false, bool bCopy=false);
void CrookMarkedGluePoints(const Point& rRef, const Point& rRad, SdrCrookMode eMode, bool bVertical=false, bool bNoContortion=false, bool bCopy=false);
void DistortMarkedGluePoints(const Rectangle& rRef, const XPolygon& rDistortedRect, bool bNoContortion=false, bool bCopy=false);
diff --git a/include/svx/svdglue.hxx b/include/svx/svdglue.hxx
index 165a7f8ff517..9b7f215f85f2 100644
--- a/include/svx/svdglue.hxx
+++ b/include/svx/svdglue.hxx
@@ -96,12 +96,12 @@ public:
Point GetAbsolutePos(const SdrObject& rObj) const;
void SetAbsolutePos(const Point& rNewPos, const SdrObject& rObj);
long GetAlignAngle() const;
- void SetAlignAngle(long nWink);
+ void SetAlignAngle(long nAngle);
long EscDirToAngle(sal_uInt16 nEsc) const;
- sal_uInt16 EscAngleToDir(long nWink) const;
- void Rotate(const Point& rRef, long nWink, double sn, double cs, const SdrObject* pObj);
- void Mirror(const Point& rRef1, const Point& rRef2, long nWink, const SdrObject* pObj);
- void Shear (const Point& rRef, long nWink, double tn, bool bVShear, const SdrObject* pObj);
+ sal_uInt16 EscAngleToDir(long nAngle) const;
+ void Rotate(const Point& rRef, long nAngle, double sn, double cs, const SdrObject* pObj);
+ void Mirror(const Point& rRef1, const Point& rRef2, long nAngle, const SdrObject* pObj);
+ void Shear (const Point& rRef, long nAngle, double tn, bool bVShear, const SdrObject* pObj);
};
#define SDRGLUEPOINT_NOTFOUND 0xFFFF
@@ -133,10 +133,10 @@ public:
void Invalidate(vcl::Window& rWin, const SdrObject* pObj) const;
// Temporaer zu setzen fuer Transformationen am Bezugsobjekt
void SetReallyAbsolute(bool bOn, const SdrObject& rObj);
- void Rotate(const Point& rRef, long nWink, double sn, double cs, const SdrObject* pObj);
+ void Rotate(const Point& rRef, long nAngle, double sn, double cs, const SdrObject* pObj);
void Mirror(const Point& rRef1, const Point& rRef2, const SdrObject* pObj);
- void Mirror(const Point& rRef1, const Point& rRef2, long nWink, const SdrObject* pObj);
- void Shear (const Point& rRef, long nWink, double tn, bool bVShear, const SdrObject* pObj);
+ void Mirror(const Point& rRef1, const Point& rRef2, long nAngle, const SdrObject* pObj);
+ void Shear (const Point& rRef, long nAngle, double tn, bool bVShear, const SdrObject* pObj);
};
diff --git a/include/svx/svdmodel.hxx b/include/svx/svdmodel.hxx
index efb5403d4946..f51b6b5c8547 100644
--- a/include/svx/svdmodel.hxx
+++ b/include/svx/svdmodel.hxx
@@ -401,7 +401,7 @@ public:
static void TakeUnitStr(FieldUnit eUnit, OUString& rStr);
void TakeMetricStr(long nVal, OUString& rStr, bool bNoUnitChars = false, sal_Int32 nNumDigits = -1) const;
- void TakeAngleStr(long nWink, OUString& rStr, bool bNoDegChar = false) const;
+ void TakeAngleStr(long nAngle, OUString& rStr, bool bNoDegChar = false) const;
void TakePercentStr(const Fraction& rVal, OUString& rStr, bool bNoPercentChar = false) const;
// RecalcPageNums is ordinarily only called by the Page.
diff --git a/include/svx/svdobj.hxx b/include/svx/svdobj.hxx
index 4f9c1ac308f3..3ae4f2355a02 100644
--- a/include/svx/svdobj.hxx
+++ b/include/svx/svdobj.hxx
@@ -422,7 +422,7 @@ protected:
void ImpForcePlusData();
- OUString GetAngleStr(long nWink, bool bNoDegChar = false) const;
+ OUString GetAngleStr(long nAngle, bool bNoDegChar = false) const;
OUString GetMetrStr(long nVal, MapUnit eWantMap=MAP_MM, bool bNoUnitChars = false) const;
// bNotMyself=true means: set only ObjList to dirty, don't mark this object as dirty.
@@ -673,15 +673,15 @@ public:
// Nbc bedeutet: 'NoBroadcast'.
virtual void NbcMove (const Size& rSiz);
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact);
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs);
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs);
virtual void NbcMirror(const Point& rRef1, const Point& rRef2);
- virtual void NbcShear (const Point& rRef, long nWink, double tn, bool bVShear);
+ virtual void NbcShear (const Point& rRef, long nAngle, double tn, bool bVShear);
virtual void Move (const Size& rSiz);
virtual void Resize(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bUnsetRelative = true);
- virtual void Rotate(const Point& rRef, long nWink, double sn, double cs);
+ virtual void Rotate(const Point& rRef, long nAngle, double sn, double cs);
virtual void Mirror(const Point& rRef1, const Point& rRef2);
- virtual void Shear (const Point& rRef, long nWink, double tn, bool bVShear);
+ virtual void Shear (const Point& rRef, long nAngle, double tn, bool bVShear);
// Die relative Position eines Zeichenobjektes ist die Entfernung der
// linken oberen Eche des logisch umschliessenden Rechtecks (SnapRect)
@@ -831,9 +831,9 @@ public:
// to be set temporarily when transforming related object(?)
void SetGlueReallyAbsolute(bool bOn);
- void NbcRotateGluePoints(const Point& rRef, long nWink, double sn, double cs);
+ void NbcRotateGluePoints(const Point& rRef, long nAngle, double sn, double cs);
void NbcMirrorGluePoints(const Point& rRef1, const Point& rRef2);
- void NbcShearGluePoints (const Point& rRef, long nWink, double tn, bool bVShear);
+ void NbcShearGluePoints (const Point& rRef, long nAngle, double tn, bool bVShear);
// is object an edge?
virtual bool IsEdge() const;
diff --git a/include/svx/svdocirc.hxx b/include/svx/svdocirc.hxx
index 14e8f4658c91..169ef35ccf2c 100644
--- a/include/svx/svdocirc.hxx
+++ b/include/svx/svdocirc.hxx
@@ -114,7 +114,7 @@ public:
virtual void NbcMove(const Size& aSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear (const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear (const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual SdrObject* DoConvertToPolyObj(bool bBezier, bool bAddText) const SAL_OVERRIDE;
protected:
diff --git a/include/svx/svdoedge.hxx b/include/svx/svdoedge.hxx
index 438c5e764188..04351a083b7c 100644
--- a/include/svx/svdoedge.hxx
+++ b/include/svx/svdoedge.hxx
@@ -267,9 +267,9 @@ public:
virtual void NbcResize(const Point& rRefPnt, const Fraction& aXFact, const Fraction& aYFact) SAL_OVERRIDE;
// #i54102# added rotate, mirrorn and shear support
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
// #102344# Added missing implementation
virtual void NbcSetAnchorPos(const Point& rPnt) SAL_OVERRIDE;
diff --git a/include/svx/svdograf.hxx b/include/svx/svdograf.hxx
index e60060968fae..cd47a2075f6c 100644
--- a/include/svx/svdograf.hxx
+++ b/include/svx/svdograf.hxx
@@ -163,9 +163,9 @@ public:
virtual SdrHdl* GetHdl(sal_uInt32 nHdlNum) const SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear (const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear (const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void NbcSetSnapRect(const Rectangle& rRect) SAL_OVERRIDE;
virtual void NbcSetLogicRect(const Rectangle& rRect) SAL_OVERRIDE;
virtual SdrObjGeoData* NewGeoData() const SAL_OVERRIDE;
diff --git a/include/svx/svdogrp.hxx b/include/svx/svdogrp.hxx
index 4a89e8f3a61d..c209532ad125 100644
--- a/include/svx/svdogrp.hxx
+++ b/include/svx/svdogrp.hxx
@@ -86,9 +86,9 @@ public:
virtual void Move(const Size& rSiz) SAL_OVERRIDE;
virtual void Resize(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bUnsetRelative = true) SAL_OVERRIDE;
- virtual void Rotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void Rotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void Mirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void Shear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void Shear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void SetAnchorPos(const Point& rPnt) SAL_OVERRIDE;
virtual void SetRelativePos(const Point& rPnt) SAL_OVERRIDE;
virtual void SetSnapRect(const Rectangle& rRect) SAL_OVERRIDE;
@@ -96,9 +96,9 @@ public:
virtual void NbcMove(const Size& rSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void NbcSetAnchorPos(const Point& rPnt) SAL_OVERRIDE;
virtual void NbcSetRelativePos(const Point& rPnt) SAL_OVERRIDE;
virtual void NbcSetSnapRect(const Rectangle& rRect) SAL_OVERRIDE;
diff --git a/include/svx/svdomeas.hxx b/include/svx/svdomeas.hxx
index 5cea5fe2de8b..4c6dbb34b87f 100644
--- a/include/svx/svdomeas.hxx
+++ b/include/svx/svdomeas.hxx
@@ -118,9 +118,9 @@ public:
virtual void NbcMove(const Size& rSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual long GetRotateAngle() const SAL_OVERRIDE;
virtual void RecalcSnapRect() SAL_OVERRIDE;
diff --git a/include/svx/svdorect.hxx b/include/svx/svdorect.hxx
index afd1d57b08b4..ef88cd275d54 100644
--- a/include/svx/svdorect.hxx
+++ b/include/svx/svdorect.hxx
@@ -106,9 +106,9 @@ public:
virtual void NbcMove(const Size& rSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual bool DoMacro(const SdrObjMacroHitRec& rRec) SAL_OVERRIDE;
virtual OUString GetMacroPopupComment(const SdrObjMacroHitRec& rRec) const SAL_OVERRIDE;
diff --git a/include/svx/svdotext.hxx b/include/svx/svdotext.hxx
index 40cbacd4c469..b700255dd00d 100644
--- a/include/svx/svdotext.hxx
+++ b/include/svx/svdotext.hxx
@@ -469,9 +469,9 @@ public:
virtual void NbcMove(const Size& rSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual bool HasTextEdit() const SAL_OVERRIDE;
virtual bool BegTextEdit(SdrOutliner& rOutl) SAL_OVERRIDE;
diff --git a/include/svx/svdovirt.hxx b/include/svx/svdovirt.hxx
index 766b8070c9ec..36cc43030eac 100644
--- a/include/svx/svdovirt.hxx
+++ b/include/svx/svdovirt.hxx
@@ -102,15 +102,15 @@ public:
virtual void NbcMove(const Size& rSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void Move(const Size& rSiz) SAL_OVERRIDE;
virtual void Resize(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bUnsetRelative = true) SAL_OVERRIDE;
- virtual void Rotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void Rotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void Mirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void Shear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void Shear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void RecalcSnapRect() SAL_OVERRIDE;
virtual const Rectangle& GetSnapRect() const SAL_OVERRIDE;
diff --git a/include/svx/svdpoev.hxx b/include/svx/svdpoev.hxx
index ef73aa49b154..e7a47c617c83 100644
--- a/include/svx/svdpoev.hxx
+++ b/include/svx/svdpoev.hxx
@@ -65,7 +65,7 @@ public:
void MoveMarkedPoints(const Size& rSiz);
void ResizeMarkedPoints(const Point& rRef, const Fraction& xFact, const Fraction& yFact);
- void RotateMarkedPoints(const Point& rRef, long nWink);
+ void RotateMarkedPoints(const Point& rRef, long nAngle);
// Hierbei entstehen eventuell beliebig viele neue Objekte:
void RipUpAtMarkedPoints() SAL_OVERRIDE;
diff --git a/include/svx/svdsnpv.hxx b/include/svx/svdsnpv.hxx
index 815656a77a39..93dff2418d86 100644
--- a/include/svx/svdsnpv.hxx
+++ b/include/svx/svdsnpv.hxx
@@ -187,7 +187,7 @@ public:
// Der Winkelfang ist unabhaengig vom Koordinatenfang
// und somit von der Einstellung IsSnapEnabled()
// Es sollten nur Werte angegeben werden fuer die gilt:
- // 36000 modulu nWink = 0
+ // 36000 modulu nAngle = 0
// Implementiert fuer:
// - Rotate (Dragging)
// - Shear (Dragging)
@@ -195,7 +195,7 @@ public:
// Persistent.
void SetAngleSnapEnabled(bool bOn) { bAngleSnapEnab=bOn; }
bool IsAngleSnapEnabled() const { return bAngleSnapEnab; }
- void SetSnapAngle(long nWink) { nSnapAngle=nWink; }
+ void SetSnapAngle(long nAngle) { nSnapAngle=nAngle; }
long GetSnapAngle() const { return nSnapAngle; }
// Ortho hat je nach Kontext verschiedene Effekte:
diff --git a/include/svx/svdoashp.hxx b/include/svx/svdoashp.hxx
index 169dd13b9dca..513813d3b8ed 100644
--- a/include/svx/svdoashp.hxx
+++ b/include/svx/svdoashp.hxx
@@ -189,15 +189,15 @@ public:
virtual void Move(const Size& rSiz) SAL_OVERRIDE;
virtual void Resize(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bUnsetRelative = true) SAL_OVERRIDE;
- virtual void Shear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void Shear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void SetSnapRect(const Rectangle& rRect) SAL_OVERRIDE;
virtual void SetLogicRect(const Rectangle& rRect) SAL_OVERRIDE;
virtual void NbcMove(const Size& rSiz) SAL_OVERRIDE;
virtual void NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact) SAL_OVERRIDE;
- virtual void NbcRotate(const Point& rRef, long nWink, double sn, double cs) SAL_OVERRIDE;
+ virtual void NbcRotate(const Point& rRef, long nAngle, double sn, double cs) SAL_OVERRIDE;
virtual void NbcMirror(const Point& rRef1, const Point& rRef2) SAL_OVERRIDE;
- virtual void NbcShear(const Point& rRef, long nWink, double tn, bool bVShear) SAL_OVERRIDE;
+ virtual void NbcShear(const Point& rRef, long nAngle, double tn, bool bVShear) SAL_OVERRIDE;
virtual void NbcSetSnapRect(const Rectangle& rRect) SAL_OVERRIDE;
virtual void NbcSetLogicRect(const Rectangle& rRect) SAL_OVERRIDE;
@@ -253,7 +253,7 @@ public:
virtual void SaveGeoData(SdrObjGeoData &rGeo) const SAL_OVERRIDE;
virtual void RestGeoData(const SdrObjGeoData &rGeo) SAL_OVERRIDE;
// need to take fObjectRotation instead of aGeo.nWink, replace it temporary
virtual bool TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegfx::B2DPolyPolygon& rPolyPolygon) const SAL_OVERRIDE;
virtual void TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const basegfx::B2DPolyPolygon& rPolyPolygon) SAL_OVERRIDE;
@@ -253,7 +253,7 @@ public:
virtual void SaveGeoData(SdrObjGeoData &rGeo) const SAL_OVERRIDE;
virtual void RestGeoData(const SdrObjGeoData &rGeo) SAL_OVERRIDE;
- // need to take fObjectRotation instead of aGeo.nWink, replace it temporary
+ // need to take fObjectRotation instead of aGeo.nAngle, replace it temporary
virtual bool TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegfx::B2DPolyPolygon& rPolyPolygon) const SAL_OVERRIDE;
virtual void TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const basegfx::B2DPolyPolygon& rPolyPolygon) SAL_OVERRIDE;
diff --git a/include/svx/svdtrans.hxx b/include/svx/svdtrans.hxx
index e79bbb8b125d..0dca9751a949 100644
--- a/include/svx/svdtrans.hxx
+++ b/include/svx/svdtrans.hxx
@@ -31,12 +31,12 @@
// Winkelangaben der DrawingEngine sind 1/100 Degree
-// #i19054# nowhere used, removed // const int nWinkDiv=100;
+// #i19054# nowhere used, removed // const int nAngleDiv=100;
// Um Winkel der DrawingEngine mit den Trigonometrischen Funktionen
// verarbeiten zu koennen, muessen sie zunaest ins Bogenmass umgerechnet
// werden. Dies gestaltet sich recht einfach mit der folgenden Konstanten
// nPi180. Sei nWink ein Winkel in 1/100 Deg so schreibt man z.B.:
// double nSin=sin(nWink*nPi180);
// Rueckwandlung entsprechend durch Teilen.
const double nPi=3.14159265358979323846;
const double nPi180=0.000174532925199432957692222; // Bei zuweing Stellen ist tan(4500*nPi180)!=1.0
@@ -79,7 +79,7 @@ void ShearXPoly(XPolygon& rPoly, const Point& rRef, double tn, bool bVShear = fa
inline double GetCrookAngle(Point& rPnt, const Point& rCenter, const Point& rRad, bool bVertical);
// Die folgenden Methoden behandeln einen Punkt eines XPolygons, wobei die
// benachbarten Kontrollpunkte des eigentlichen Punktes ggf. in pC1/pC2
// uebergeben werden. Ueber rSin/rCos wird gleichzeitig sin(nWink) und cos(nWink)
// zurueckgegeben.
// Der Rueckgabewinkel ist hier ebenfalls in Rad.
double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCenter,
@@ -133,17 +133,17 @@ inline void ShearPoint(Point& rPnt, const Point& rRef, double tn, bool bVShear)
inline double GetCrookAngle(Point& rPnt, const Point& rCenter, const Point& rRad, bool bVertical)
{
- double nWink;
+ double nAngle;
if (bVertical) {
long dy=rPnt.Y()-rCenter.Y();
- nWink=(double)dy/(double)rRad.Y();
+ nAngle=(double)dy/(double)rRad.Y();
rPnt.Y()=rCenter.Y();
} else {
long dx=rCenter.X()-rPnt.X();
- nWink=(double)dx/(double)rRad.X();
+ nAngle=(double)dx/(double)rRad.X();
rPnt.X()=rCenter.X();
}
- return nWink;
+ return nAngle;
}
/**************************************************************************************************/
@@ -157,7 +157,7 @@ inline double GetCrookAngle(Point& rPnt, const Point& rCenter, const Point& rRad
SVX_DLLPUBLIC long GetAngle(const Point& rPnt);
long NormAngle180(long a); // Winkel normalisieren auf -180.00..179.99
SVX_DLLPUBLIC long NormAngle360(long a); // Winkel normalisieren auf 0.00..359.99
-sal_uInt16 GetAngleSector(long nWink); // Sektor im kartesischen Koordinatensystem bestimmen
+sal_uInt16 GetAngleSector(long nAngle); // Sektor im kartesischen Koordinatensystem bestimmen
// Berechnet die Laenge von (0,0) via a^2 + b^2 = c^2
// Zur Vermeidung von Ueberlaeufen werden ggf. einige Stellen ignoriert.
long GetLen(const Point& rPnt);
@@ -31,12 +31,12 @@
// verarbeiten zu koennen, muessen sie zunaest ins Bogenmass umgerechnet
// werden. Dies gestaltet sich recht einfach mit der folgenden Konstanten
-// nPi180. Sei nWink ein Winkel in 1/100 Deg so schreibt man z.B.:
-// double nSin=sin(nWink*nPi180);
+// nPi180. Sei nAngle ein Winkel in 1/100 Deg so schreibt man z.B.:
+// double nSin=sin(nAngle*nPi180);
// Rueckwandlung entsprechend durch Teilen.
const double nPi=3.14159265358979323846;
@@ -79,7 +79,7 @@ void ShearXPoly(XPolygon& rPoly, const Point& rRef, double tn, bool bVShear = fa
// Die folgenden Methoden behandeln einen Punkt eines XPolygons, wobei die
// benachbarten Kontrollpunkte des eigentlichen Punktes ggf. in pC1/pC2
-// uebergeben werden. Ueber rSin/rCos wird gleichzeitig sin(nWink) und cos(nWink)
+// uebergeben werden. Ueber rSin/rCos wird gleichzeitig sin(nAngle) und cos(nAngle)
// zurueckgegeben.
// Der Rueckgabewinkel ist hier ebenfalls in Rad.